==> haskell-wreq-0.5.3.2-300-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-wreq.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 wreq
version:              0.5.3.2
visibility:           public
id:                   wreq-0.5.3.2-4JqVzJoioZz7pqshMz2ieZ
key:                  wreq-0.5.3.2-4JqVzJoioZz7pqshMz2ieZ
license:              BSD-3-Clause
copyright:            2014 Bryan O'\''Sullivan
maintainer:           bos@serpentine.com
author:               Bryan O'\''Sullivan <bos@serpentine.com>
homepage:             http://www.serpentine.com/wreq
synopsis:             An easy-to-use HTTP client library.
description:

    A web client library that is designed for ease of use.

    Tutorial: <http://www.serpentine.com/wreq/tutorial.html>

    Features include:

    * Simple but powerful `lens`-based API

    * A solid test suite, and built on reliable libraries like
    http-client and lens

    * Session handling includes connection keep-alive and pooling, and
    cookie persistence

    * Automatic response body decompression

    * Powerful multipart form and file upload handling

    * Support for JSON requests and responses, including navigation of
    schema-less responses

    * Basic and OAuth2 bearer authentication

    * Early TLS support via the tls package

category:             Web
abi:                  13c0ee9b49f4fd2c42971782fe1f5ac4
exposed:              True
exposed-modules:
    Network.Wreq Network.Wreq.Cache Network.Wreq.Cache.Store
    Network.Wreq.Lens Network.Wreq.Session Network.Wreq.Types

hidden-modules:
    Network.Wreq.Internal Network.Wreq.Internal.AWS
    Network.Wreq.Internal.Lens Network.Wreq.Internal.Link
    Network.Wreq.Internal.OAuth1 Network.Wreq.Internal.Types
    Network.Wreq.Lens.Machinery Network.Wreq.Lens.TH Paths_wreq

import-dirs:          /usr/lib/ghc-8.10.2/site-local/wreq-0.5.3.2
library-dirs:         /usr/lib/ghc-8.10.2/site-local/wreq-0.5.3.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/wreq-0.5.3.2
hs-libraries:         HSwreq-0.5.3.2-4JqVzJoioZz7pqshMz2ieZ
depends:
    aeson-1.5.4.1-A0L815KAfIF5MogEzEmc2
    attoparsec-0.13.2.4-6s9PGXpTa8d5vs3WhgDbsJ
    authenticate-oauth-1.6.0.1-2xYMQjLUAerLe4Lo9zw9cB base-4.14.1.0
    base16-bytestring-0.1.1.7-7MnoTKrQfBC3WeMx0LqUK0
    bytestring-0.10.10.0 case-insensitive-1.2.1.0-AiSw8QonpUthLZMfaO6Sw
    containers-0.6.2.1 cryptonite-0.27-GQDFsV0e2GLJaPfeS4zGY1
    exceptions-0.10.4 ghc-prim-0.6.1
    hashable-1.3.0.0-B2he7mV2CaG3Rgw4mjNDxl
    http-client-0.7.2.1-B0lg1UYQ2QqEhZ1ekz226X
    http-client-tls-0.3.5.3-2smD5PwnJlB8c2o243jfzB
    http-types-0.12.3-5OCzJ9s2WGTJNDPAqKfT5m
    lens-4.19.2-CM7xks4zopx8m7aqAk8opQ
    lens-aeson-1.1-BsfKCWJguGvFt63Dztyfl
    memory-0.15.0-359cYXe7lRF64CAN0G53fp
    mime-types-0.1.0.9-7WG5UcXzH6N6zzQ8X9LvyP
    psqueues-0.2.7.2-B6H2awKpWni2BUMB9aO72q template-haskell-2.16.0.0
    text-1.2.3.2 time-1.9.3
    time-locale-compat-0.1.1.5-75n5v6JklqyMdEmBwWBxO
    unordered-containers-0.2.13.0-KjldV6HJtaDB1Zm2KKQlBR

haddock-interfaces:   /usr/share/doc/haskell-wreq/html/wreq.haddock
haddock-html:         /usr/share/doc/haskell-wreq/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-wreq-0.5.3.2-302-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-wreq.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 wreq
version:              0.5.3.2
visibility:           public
id:                   wreq-0.5.3.2-6LNYtntQWZr6XGOsBLLKEp
key:                  wreq-0.5.3.2-6LNYtntQWZr6XGOsBLLKEp
license:              BSD-3-Clause
copyright:            2014 Bryan O'\''Sullivan
maintainer:           bos@serpentine.com
author:               Bryan O'\''Sullivan <bos@serpentine.com>
homepage:             http://www.serpentine.com/wreq
synopsis:             An easy-to-use HTTP client library.
description:

    A web client library that is designed for ease of use.

    Tutorial: <http://www.serpentine.com/wreq/tutorial.html>

    Features include:

    * Simple but powerful `lens`-based API

    * A solid test suite, and built on reliable libraries like
    http-client and lens

    * Session handling includes connection keep-alive and pooling, and
    cookie persistence

    * Automatic response body decompression

    * Powerful multipart form and file upload handling

    * Support for JSON requests and responses, including navigation of
    schema-less responses

    * Basic and OAuth2 bearer authentication

    * Early TLS support via the tls package

category:             Web
abi:                  e2b26b823134807bdff8a051b1780c17
exposed:              True
exposed-modules:
    Network.Wreq Network.Wreq.Cache Network.Wreq.Cache.Store
    Network.Wreq.Lens Network.Wreq.Session Network.Wreq.Types

hidden-modules:
    Network.Wreq.Internal Network.Wreq.Internal.AWS
    Network.Wreq.Internal.Lens Network.Wreq.Internal.Link
    Network.Wreq.Internal.OAuth1 Network.Wreq.Internal.Types
    Network.Wreq.Lens.Machinery Network.Wreq.Lens.TH Paths_wreq

import-dirs:          /usr/lib/ghc-8.10.2/site-local/wreq-0.5.3.2
library-dirs:         /usr/lib/ghc-8.10.2/site-local/wreq-0.5.3.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/wreq-0.5.3.2
hs-libraries:         HSwreq-0.5.3.2-6LNYtntQWZr6XGOsBLLKEp
depends:
    aeson-1.5.4.1-A0L815KAfIF5MogEzEmc2
    attoparsec-0.13.2.4-6s9PGXpTa8d5vs3WhgDbsJ
    authenticate-oauth-1.6.0.1-IS4OpEuNwEWBrY2bwv6cwz base-4.14.1.0
    base16-bytestring-0.1.1.7-7MnoTKrQfBC3WeMx0LqUK0
    bytestring-0.10.10.0 case-insensitive-1.2.1.0-AiSw8QonpUthLZMfaO6Sw
    containers-0.6.2.1 cryptonite-0.27-1DDx0Ud3spVAZd9MKUflvw
    exceptions-0.10.4 ghc-prim-0.6.1
    hashable-1.3.0.0-B2he7mV2CaG3Rgw4mjNDxl
    http-client-0.7.2.1-9FrWjd6tGGR6rQlg6WWv38
    http-client-tls-0.3.5.3-BhhnVMGJv6d8ufpg4EaYTN
    http-types-0.12.3-5OCzJ9s2WGTJNDPAqKfT5m
    lens-4.19.2-CM7xks4zopx8m7aqAk8opQ
    lens-aeson-1.1-BsfKCWJguGvFt63Dztyfl
    memory-0.15.0-359cYXe7lRF64CAN0G53fp
    mime-types-0.1.0.9-7WG5UcXzH6N6zzQ8X9LvyP
    psqueues-0.2.7.2-B6H2awKpWni2BUMB9aO72q template-haskell-2.16.0.0
    text-1.2.3.2 time-1.9.3
    time-locale-compat-0.1.1.5-75n5v6JklqyMdEmBwWBxO
    unordered-containers-0.2.13.0-KjldV6HJtaDB1Zm2KKQlBR

haddock-interfaces:   /usr/share/doc/haskell-wreq/html/wreq.haddock
haddock-html:         /usr/share/doc/haskell-wreq/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
